@@ -4,7 +4,7 @@ import textnorm
 import nltk
 
 # Download stpwords
-nltk.download("stopwords")
+nltk.download("stopwords", quiet=True)
 
 # Import nltk for stopwords
 from nltk.corpus import stopwords
